@@ -4,12 +4,13 @@
 
 #pragma once
 
+#include <span>
+
 #include <wpi/SmallVector.h>
-#include <wpi/span.h>
 
 namespace frc2 {
 template <typename T>
-void SetInsert(wpi::SmallVectorImpl<T>& vector, wpi::span<T> toAdd) {
+void SetInsert(wpi::SmallVectorImpl<T>& vector, std::span<T> toAdd) {
   for (auto addCommand : toAdd) {
     bool exists = false;
     for (auto existingCommand : vector) {
